// LaunchBar Action Script

function run(argument) {
    if (argument == undefined) {
        // Inform the user that there was no argument
        LaunchBar.alert('No query string');
    } else {
        var results = LaunchBar.execute('/usr/local/bin/howdoi', '-j' , argument);

        if ((/^Sorry/).test(results)) {
        	return [{title: 'No results found', icon: 'font-awesome:exclamation-circle'}];
        }

        var data = JSON.parse(results),
            answer = data[0]['answer'],
        	url = data[0]['link'],
        	tempfile = Action.supportPath + '/answer.temp',
        	pygments_theme = 'monokai';

        File.writeText(answer, tempfile)

        var style = LaunchBar.execute('/usr/local/bin/pygmentize', '-S', pygments_theme, '-f', 'html')

        var code = LaunchBar.execute('/usr/local/bin/pygmentize', '-g', '-f', 'html', tempfile)

        var html =`<!DOCTYPE html>
<html>
<head>
<meta charset="utf-8">
<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
<title></title>
<style>
body { font-family: Menlo; font-size: 18px; background-color: #444; }
${style}
</style>
</head>
<body>
${code}
</body>
</html>`

		File.writeText(html, tempfile + '.html')

        return [
        {
        	title: 'Quick Look Answer',
        	icon: 'font-awesome:eye',
        	action: 'quickLookAnswer',
        	actionArgument: tempfile + '.html'
        },
        {
        	title: 'Copy to clipboard',
        	subtitle: 'Copy full answer to your clipboard',
        	action: 'copyAnswer',
        	actionArgument: answer,
        	icon: 'font-awesome:clone'
        },
        {
        	title : 'Open Answer URL',
        	subtitle : url,
        	url: data[0]['link'],
        	icon: 'font-awesome:safari'
        },
        {
        	title : 'Save Query',
        	action: 'saveQuery',
        	actionArgument: argument,
        	icon: 'font-awesome:save'
        }
        ];
    }
}

function quickLookAnswer (path) {
	LaunchBar.openQuickLook(File.fileURLForPath(path));
}

function saveQuery (query) {
	LaunchBar.execute('/usr/local/bin/howdoi', '--save', query)
	LaunchBar.hide();
}

function copyAnswer (answer) {
	LaunchBar.setClipboardString(answer);
	LaunchBar.hide();
}
